def help():
    print('usage: nhm [-h] [login] [logout] [newnet] [fork] [merge]')
    print('\t [upload] [push] [pull] [add] [commit] [init]')
    print('\n')
    print('Nethub-Manager v.0.0.8')
    print('\n')
    print('optional arguments:')
    print('  -h, --help\t\t\t\t\tshow this message and exit')
    print('  login\t\t\t\t\t\tlogin to nethub-server')
    print('  logout\t\t\t\t\tlogout from nethub-server')
    print('  newnet <name_of_new_net> [-l, --local]\tcreate neural net project, remote or local')
    print('  fork <original_project> <new_project>\t\tfork local project')
    print('  merge <master_net> <second_net>\t\tmerge second net to master net')
    print('  upload\t\t\t\t\tupload local project to nethub-server')
    print('  push\t\t\t\t\t\tpush changes to nethub-server')
    print('  add\t\t\t\t\t\tstage changes')
    print('  commit\t\t\t\t\tcommit project changes')
    print('  init\t\t\t\t\t\tinitialization')
